@@ -40,7 +40,6 @@ class TVarFigure1D(pg.GraphicsLayout):
 
         # Set up the y axis
         self.yaxis = AxisItem("left")
-        self.yaxis.setWidth(100)
 
         # Creating axes to bound the plots with lines
         self.xaxis2 = DateAxis(orientation='top', showValues=False)
@@ -56,6 +55,9 @@ class TVarFigure1D(pg.GraphicsLayout):
                                                                 'right': self.yaxis2,
                                                                 'top': self.xaxis2}, viewBox=vb)
 
+        #Turn off zooming in on the y-axis, time resolution is much more important
+        self.plotwindow.setMouseEnabled(y=pytplot.tplot_opt_glob['y_axis_zoom'])
+
         if pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']['border']:
             self.plotwindow.showAxis("top")
             self.plotwindow.showAxis("right")
