@@ -3,7 +3,6 @@
 # This software was developed at the University of Colorado's Laboratory for Atmospheric and Space Physics.
 # Verify current version before use at: https://github.com/MAVENSDC/PyTplot
 
-from pytplot import data_quants
 from . import tplot_utilities
 from bokeh.models import Span
 import pytplot
@@ -85,15 +84,15 @@ def timebar(t, varname = None, databar = False, delete = False, color = 'black',
             tbar['line_color'] = pytplot.tplot_utilities.rgb_color(color)[0]
             tbar['line_width'] = thick
             tbar['line_dash'] = dash_pattern
-            for name in data_quants:
-                temp_data_quants = data_quants[name]
+            for name in pytplot.data_quants:
+                temp_data_quants = pytplot.data_quants[name]
                 temp_data_quants.attrs['plot_options']['time_bar'].append(tbar)
     #if varname specified
     else:
         if not isinstance(varname, list):
             varname = [varname]
         for j in varname:
-            if j not in data_quants.keys():
+            if j not in pytplot.data_quants.keys():
                 print(str(j) + "is currently not in pytplot")
             else:
                 num_bars = len(t)
@@ -104,6 +103,6 @@ def timebar(t, varname = None, databar = False, delete = False, color = 'black',
                     tbar['line_color'] = pytplot.tplot_utilities.rgb_color(color)[0]
                     tbar['line_width'] = thick
                     tbar['line_dash'] = dash_pattern
-                    temp_data_quants = data_quants[j]
+                    temp_data_quants = pytplot.data_quants[j]
                     temp_data_quants.attrs['plot_options']['time_bar'].append(tbar)
     return
\ No newline at end of file
