@@ -4,19 +4,18 @@
 # Verify current version before use at: https://github.com/MAVENSDC/PyTplot
 
 from __future__ import division
-from pytplot import lim_info, tplot_opt_glob
+import pytplot
 
 from .xlim import xlim
 
 def tlimit(arg):
-    global lim_info
-    
+
     if arg is 'last':
-        xlast = lim_info['xlast']
-        lim_info['xlast'] = tplot_opt_glob['x_range']
-        tplot_opt_glob['x_range'] = xlast
+        xlast = pytplot.lim_info['xlast']
+        pytplot.lim_info['xlast'] = pytplot.tplot_opt_glob['x_range']
+        pytplot.tplot_opt_glob['x_range'] = xlast
     elif arg is 'full':
-        tplot_opt_glob['x_range'] = lim_info['xfull'] 
+        pytplot.tplot_opt_glob['x_range'] = pytplot.lim_info['xfull']
     elif isinstance(arg, list):
         minn = arg[0]
         maxx = arg[1]
