@@ -137,6 +137,15 @@ def set_tplot_options(option, value, old_tplot_opt_glob):
     elif option == 'axis_font_size':
         new_tplot_opt_glob['axis_font_size'] = value
 
+    elif option == 'axis_tick_num':
+        new_tplot_opt_glob['axis_tick_num'] = value
+
+    elif option == 'yaxis_width':
+        new_tplot_opt_glob['yaxis_width'] = value
+
+    elif option == 'y_axis_zoom':
+        new_tplot_opt_glob['y_axis_zoom'] = value
+
     else:
         print("Unknown option supplied: " + str(option))
 
